==> apache-plc4x-0.6.0-source-release.zip: apache-plc4x-0.6.0/plc4j/integrations/apache-camel/src/test/java/org/apache/plc4x/camel/Plc4XEndpointTest.java <==
/*
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
*/
package org.apache.plc4x.camel;

import org.apache.camel.Component;
import org.apache.camel.Processor;
import org.junit.Before;
import org.junit.Test;

import static org.hamcrest.core.Is.is;
import static org.hamcrest.core.IsNull.notNullValue;
import static org.junit.Assert.assertThat;
import static org.mockito.Mockito.mock;

public class Plc4XEndpointTest {

    Plc4XEndpoint SUT;

    @Before
    public void setUp() {
        SUT = new Plc4XEndpoint("plc4x:mock:10.10.10.1/1/1", mock(Component.class));
    }

    // TODO: figure out what this is
    @Test
    public void createProducer() throws Exception {
        assertThat(SUT.createProducer(), notNullValue());
    }

    @Test
    public void createConsumer() throws Exception {
        assertThat(SUT.createConsumer(mock(Processor.class)), notNullValue());
    }

    @Test
    public void isSingleton() {
        assertThat(SUT.isSingleton(), is(true));
    }

}

==> apache-plc4x-0.8.0-source-release.zip: apache-plc4x-0.8.0/plc4j/integrations/apache-camel/src/test/java/org/apache/plc4x/camel/Plc4XEndpointTest.java <==
/*
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
*/
package org.apache.plc4x.camel;

import org.apache.camel.Component;
import org.apache.camel.Processor;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import static org.hamcrest.core.Is.is;
import static org.hamcrest.core.IsNull.notNullValue;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.mockito.Mockito.mock;

public class Plc4XEndpointTest {

    Plc4XEndpoint SUT;

    @BeforeEach
    public void setUp() {
        SUT = new Plc4XEndpoint("plc4x:mock:10.10.10.1/1/1", mock(Component.class));
    }

    // TODO: figure out what this is
    @Test
    public void createProducer() throws Exception {
        assertThat(SUT.createProducer(), notNullValue());
    }

    @Test
    public void createConsumer() throws Exception {
        assertThat(SUT.createConsumer(mock(Processor.class)), notNullValue());
    }

    @Test
    public void isSingleton() {
        assertThat(SUT.isSingleton(), is(true));
    }

}
